🔸ISRO ASAR — PolSARtools 0.9 documentation

Skip to main content
`Ctrl`+`K`

# 🔸ISRO ASAR

## RSLC (`isro_asar`)

The isro_asar function extracts S2/C3/C4/T3 matrix elements from the given ASAR RSLC .h5 file and saves them into a directory.

polsartools.isro_asar(inFile, mat='T3', azlks=5, rglks=5, fmt='tif', cog=False, ovr=[2, 4, 8, 16], comp=False, out_dir=None, recip=False, max_workers=None, calibration_constant=42)

  Extracts PolSAR matrix elements from a ISRO ASAR RSLC HDF5 file and saves them as slant range raster files.

  This function supports both dual-polarimetric and full-polarimetric RSLC data. It performs multi-looking using specified azimuth and range looks, and outputs matrix elements in either GeoTIFF or binary format. Optional support for Cloud Optimized GeoTIFFs (COGs), and TIFF compression.

  Examples

      >>> isro_asar("path_to_file.h5", azlks=30, rglks=15)
      Extracts matrix elements with 5x5 multi-looking and saves them in the default output folder.

      >>> isro_asar("path_to_file.h5", mat='T3', fmt='tif', cog=True, comp=True)
      Extracts T3 matrix elements and saves them as compressed Cloud Optimized GeoTIFFs.

  Parameters:

    - inFile (str) – Path to the NISAR RSLC HDF5 file containing dual-pol or full-pol SAR data.

    - mat (str, optional (default='T3')) – Type of matrix to extract. Valid options for Full-pol: ‘S2’, ‘C4, ‘C3’, ‘T4’, ‘T3’, ‘C2HX’, ‘C2VX’, ‘C2HV’,’T2HV’and Dual-pol: ‘Sxy’,’C2’.

    - azlks (int, optional (default=5)) – Number of azimuth looks for multi-looking.

    - rglks (int, optional (default=5)) – Number of range looks for multi-looking.

    - fmt ({'tif', 'bin'}, optional (default='tif')) – Output format: - ‘tif’: GeoTIFF in slant range - ‘bin’: Raw binary format

    - cog (bool, optional (default=False)) – If True, outputs will be saved as Cloud Optimized GeoTIFFs with internal tiling and overviews.

    - ovr (list of int, optional (default=[2, 4, 8, 16])) – Overview levels for COG generation. Ignored if cog=False.

    - comp (bool, optional (default=False)) – If True, applies LZW compression to GeoTIFF outputs.

    - out_dir (str or None, optional (default=None)) – Directory to save output files. If None, a folder named after the matrix type will be created in the same location as the input file.

    - recip (bool, optional (default=False)) – If True, scattering matrix reciprocal symmetry is applied, i.e, S_HV = S_VH.